==> makatto-1.5.0.tgz: package/bin/makatto.js <==
#!/usr/bin/env node

var argsparser = require("argsparser");
var fs         = require("fs");
var path       = require("path");
var proc       = require("../lib/process.js");
var watcher    = require("../lib/watcher.js");
var builder    = require("../lib/builder.js");
var browser    = require("../lib/browser.js");
var Server     = require("../lib/server.js").Server;
var args       = argsparser.parse();
var config     = global.config = {};
var server;

if (process.argv.length === 2) {
	config = proc.getConfig("makatto-config.js");
}
else {
	config = proc.getConfig(args["--config"]);
}

if (args["--server"]) {
	config.server = args["--server"];
}
if (config.server) {
	if (args["--port"]) {
		config.port = args["--port"];
	}
	if (args["--livereload"]) {
		config.livereload = true;
	}
}

if (args["--src"]) {
	config.srcDir = args["--src"];
}
if (args["--dist"]) {
	config.distDir = args["--dist"];
}
if (args["--tplroot"]) {
	config.templateRoot = args["--tplroot"];
}
if (args["--cssmin"]) {
	config.cssmin = args["--cssmin"];
}
if (args["--jsmin"]) {
	config.jsmin = args["--jsmin"];
}
if (args["--imgmin"]) {
	config.imgmin = args["--imgmin"];
}
if (args["--imgminMaxsize"]) {
	config.imgminMaxsize = args["--imgminMaxsize"];
}
if (args["--devel"]) {
	config.devel = !!args["--devel"];
}

global.config = config;

if (!fs.existsSync(config.srcDir)) {
	console.log("Source dir does not exist: " + config.srcDir);
	proc.quit();
}
if (!fs.existsSync(config.distDir)) {
	console.log("Dist dir does not exist: " + config.distDir);
	proc.quit();
}

if (config.server) {
	proc.init();
	
	server = new Server(config.port, config.httpRoot, config.livereload);
	server.start(function() {
		console.log("Listening on port: " + config.port);
		
		builder.build(config.srcDir, config.distDir);
		
		config.browsers.forEach(function(browserPath) {
			browser.start(browserPath, "http://localhost:" + config.port + "/" + config.templateRoot);
		});
		
		watcher.watchDir(config.srcDir, function(inputDir, fileName) {
			builder.build(config.srcDir, config.distDir, false);
			
			var filePath = inputDir + "/" + fileName;
			var relativeFilePath = path.relative(config.srcDir + "/html", filePath);
			
			server.sockets.forEach(function(_socket, i) {
				_socket && browser.refresh(relativeFilePath, _socket, 500);
			});
		});
	});
}
else {
	console.log("Building to: " + config.distDir);
	builder.build(config.srcDir, config.distDir, true);
}

==> makatto-1.5.1.tgz: package/bin/makatto.js <==
#!/usr/bin/env node

var argsparser = require("argsparser");
var fs         = require("fs");
var path       = require("path");
var proc       = require("../lib/process.js");
var watcher    = require("../lib/watcher.js");
var builder    = require("../lib/builder.js");
var browser    = require("../lib/browser.js");
var Server     = require("../lib/server.js").Server;
var args       = argsparser.parse();
var config     = global.config = {};
var server;

if (process.argv.length === 2) {
	config = proc.getConfig("makatto-config.js");
}
else {
	config = proc.getConfig(args["--config"]);
}

if (args["--server"]) {
	config.server = args["--server"];
}
if (config.server) {
	if (args["--port"]) {
		config.port = args["--port"];
	}
	if (args["--livereload"]) {
		config.livereload = true;
	}
}

if (args["--src"]) {
	config.srcDir = args["--src"];
}
if (args["--dist"]) {
	config.distDir = args["--dist"];
}
if (args["--tplroot"]) {
	config.templateRoot = args["--tplroot"];
}
if (args["--cssmin"]) {
	config.cssmin = args["--cssmin"];
}
if (args["--jsmin"]) {
	config.jsmin = args["--jsmin"];
}
if (args["--imgmin"]) {
	config.imgmin = args["--imgmin"];
}
if (args["--imgminMaxsize"]) {
	config.imgminMaxsize = args["--imgminMaxsize"];
}
if (args["--devel"]) {
	config.devel = !!args["--devel"];
}

global.config = config;

if (!fs.existsSync(config.srcDir)) {
	console.log("Source dir does not exist: " + config.srcDir);
	proc.quit();
}
if (!fs.existsSync(config.distDir)) {
	console.log("Dist dir does not exist: " + config.distDir);
	proc.quit();
}

if (config.server) {
	proc.init();
	
	server = new Server(config.port, config.httpRoot, config.livereload);
	server.start(function() {
		console.log("Listening on port: " + config.port);
		
		builder.build(config.srcDir, config.distDir);
		
		config.browsers.forEach(function(browserPath) {
			browser.start(browserPath, "http://localhost:" + config.port + "/" + (config.templateRoot === "/" ? "" : config.templateRoot));
		});
		
		watcher.watchDir(config.srcDir, function(inputDir, fileName) {
			builder.build(config.srcDir, config.distDir, false);
			
			var filePath = inputDir + "/" + fileName;
			var relativeFilePath = path.relative(config.srcDir + "/html", filePath);
			
			server.sockets.forEach(function(_socket, i) {
				_socket && browser.refresh(relativeFilePath, _socket, 500);
			});
		});
	});
}
else {
	console.log("Building to: " + config.distDir);
	builder.build(config.srcDir, config.distDir, true);
}
